@@ -39,19 +39,12 @@
 #define PLUGIN_PRIORITY_MAX 1
 #define PLUGIN_PRIORITY_DEFAULT 100
 
-typedef enum
-{
-        MATE_SETTINGS_PLUGIN_LOADER_C,
-        MATE_SETTINGS_PLUGIN_LOADER_PY
-} MateSettingsPluginLoader;
-
 struct MateSettingsPluginInfoPrivate
 {
         char                    *file;
         GSettings               *settings;
 
         char                    *location;
-        MateSettingsPluginLoader loader;
         GTypeModule             *module;
 
         char                    *name;
@@ -66,8 +59,7 @@ struct MateSettingsPluginInfoPrivate
         int                      active : 1;
 
         /* A plugin is unavailable if it is not possible to activate it
-           due to an error loading the plugin module (e.g. for Python plugins
-           when the interpreter has not been correctly initializated) */
+           due to an error loading the plugin module */
         int                      available : 1;
 
         guint                    enabled_notification_id;
@@ -86,7 +78,7 @@ enum {
 
 static guint signals [LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (MateSettingsPluginInfo, mate_settings_plugin_info, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (MateSettingsPluginInfo, mate_settings_plugin_info, G_TYPE_OBJECT)
 
 static void
 mate_settings_plugin_info_finalize (GObject *object)
@@ -151,8 +143,6 @@ mate_settings_plugin_info_class_init (MateSettingsPluginInfoClass *klass)
                               g_cclosure_marshal_VOID__VOID,
                               G_TYPE_NONE,
                               0);
-
-        g_type_class_add_private (klass, sizeof (MateSettingsPluginInfoPrivate));
 }
 
 static void
@@ -213,20 +203,6 @@ mate_settings_plugin_info_fill_from_file (MateSettingsPluginInfo *info,
                 goto out;
         }
 
-        /* Get the loader for this plugin */
-        str = g_key_file_get_string (plugin_file, PLUGIN_GROUP, "Loader", NULL);
-        if (str != NULL && strcmp (str, "python") == 0) {
-                info->priv->loader = MATE_SETTINGS_PLUGIN_LOADER_PY;
-#ifndef ENABLE_PYTHON
-                g_warning ("Cannot load Python plugin '%s' since mate_settings was not "
-                           "compiled with Python support.", filename);
-                goto out;
-#endif
-        } else {
-                info->priv->loader = MATE_SETTINGS_PLUGIN_LOADER_C;
-        }
-        g_free (str);
-
         /* Get Name */
         str = g_key_file_get_locale_string (plugin_file, PLUGIN_GROUP, "Name", NULL, NULL);
         if (str != NULL) {
@@ -360,70 +336,20 @@ load_plugin_module (MateSettingsPluginInfo *info)
 
         mate_settings_profile_start ("%s", info->priv->location);
 
-        switch (info->priv->loader) {
-                case MATE_SETTINGS_PLUGIN_LOADER_C:
-                        dirname = g_path_get_dirname (info->priv->file);
-                        g_return_val_if_fail (dirname != NULL, FALSE);
+        dirname = g_path_get_dirname (info->priv->file);
+        g_return_val_if_fail (dirname != NULL, FALSE);
 
-                        path = g_module_build_path (dirname, info->priv->location);
-                        g_free (dirname);
-                        g_return_val_if_fail (path != NULL, FALSE);
+        path = g_module_build_path (dirname, info->priv->location);
+        g_free (dirname);
+        g_return_val_if_fail (path != NULL, FALSE);
 
-                        info->priv->module = G_TYPE_MODULE (mate_settings_module_new (path));
-                        g_free (path);
-
-                        break;
-
-#ifdef ENABLE_PYTHON
-                case MATE_SETTINGS_PLUGIN_LOADER_PY:
-                {
-                        char *dir;
-
-                        if (!mate_settings_python_init ()) {
-                                /* Mark plugin as unavailable and fails */
-                                info->priv->available = FALSE;
-
-                                g_warning ("Cannot load Python plugin '%s' since mate_settings "
-                                           "was not able to initialize the Python interpreter.",
-                                           info->priv->name);
-
-                                goto out;
-                        }
-
-                        dir = g_path_get_dirname (info->priv->file);
-
-                        g_return_val_if_fail ((info->priv->location != NULL) &&
-                                              (info->priv->location[0] != '\0'),
-                                              FALSE);
-
-                        info->priv->module = G_TYPE_MODULE (
-                                        mate_settings_python_module_new (dir, info->priv->location));
-
-                        g_free (dir);
-                        break;
-                }
-#endif
-                default:
-                        g_return_val_if_reached (FALSE);
-        }
+        info->priv->module = G_TYPE_MODULE (mate_settings_module_new (path));
+        g_free (path);
 
         if (!g_type_module_use (info->priv->module)) {
-                switch (info->priv->loader) {
-                        case MATE_SETTINGS_PLUGIN_LOADER_C:
-                                g_warning ("Cannot load plugin '%s' since file '%s' cannot be read.",
-                                           info->priv->name,
-                                           mate_settings_module_get_path (MATE_SETTINGS_MODULE (info->priv->module)));
-                                break;
-
-                        case MATE_SETTINGS_PLUGIN_LOADER_PY:
-                                g_warning ("Cannot load Python plugin '%s' since file '%s' cannot be read.",
-                                           info->priv->name,
-                                           info->priv->location);
-                                break;
-
-                        default:
-                                g_return_val_if_reached (FALSE);
-                }
+                g_warning ("Cannot load plugin '%s' since file '%s' cannot be read.",
+                           info->priv->name,
+                           mate_settings_module_get_path (MATE_SETTINGS_MODULE (info->priv->module)));
 
                 g_object_unref (G_OBJECT (info->priv->module));
                 info->priv->module = NULL;
@@ -434,26 +360,12 @@ load_plugin_module (MateSettingsPluginInfo *info)
                 goto out;
         }
 
-        switch (info->priv->loader) {
-                case MATE_SETTINGS_PLUGIN_LOADER_C:
-                        info->priv->plugin =
-                                MATE_SETTINGS_PLUGIN (mate_settings_module_new_object (MATE_SETTINGS_MODULE (info->priv->module)));
-                        break;
-
-#ifdef ENABLE_PYTHON
-                case MATE_SETTINGS_PLUGIN_LOADER_PY:
-                        info->priv->plugin =
-                                MATE_SETTINGS_PLUGIN (mate_settings_python_module_new_object (MATE_SETTINGS_PYTHON_MODULE (info->priv->module)));
-                        break;
-#endif
-
-                default:
-                        g_return_val_if_reached (FALSE);
-        }
+        info->priv->plugin =
+                MATE_SETTINGS_PLUGIN (mate_settings_module_new_object (MATE_SETTINGS_MODULE (info->priv->module)));
 
         g_type_module_unuse (info->priv->module);
         ret = TRUE;
- out:
+out:
         mate_settings_profile_end ("%s", info->priv->location);
         return ret;
 }
@@ -609,6 +521,6 @@ mate_settings_plugin_info_set_schema (MateSettingsPluginInfo *info,
 	if (priority > 0)
 		info->priv->priority = priority;
 
-	g_signal_connect (G_OBJECT (info->priv->settings), "changed::active", 
+	g_signal_connect (G_OBJECT (info->priv->settings), "changed::active",
 			  G_CALLBACK (plugin_enabled_cb), info);
 }
