@@ -130,11 +130,7 @@ main (int argc, char **argv)
 
         ret = 1;
 
-        if (! g_thread_supported ()) {
-                g_thread_init (NULL);
-        }
         dbus_g_thread_init ();
-        g_type_init ();
 
         connection = get_system_bus ();
         if (connection == NULL) {
