@@ -31,14 +31,12 @@ struct MsdKeybindingsPluginPrivate {
         MsdKeybindingsManager *manager;
 };
 
-#define MSD_KEYBINDINGS_PLUGIN_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), MSD_TYPE_KEYBINDINGS_PLUGIN, MsdKeybindingsPluginPrivate))
-
-MATE_SETTINGS_PLUGIN_REGISTER (MsdKeybindingsPlugin, msd_keybindings_plugin)
+MATE_SETTINGS_PLUGIN_REGISTER_WITH_PRIVATE (MsdKeybindingsPlugin, msd_keybindings_plugin)
 
 static void
 msd_keybindings_plugin_init (MsdKeybindingsPlugin *plugin)
 {
-        plugin->priv = MSD_KEYBINDINGS_PLUGIN_GET_PRIVATE (plugin);
+        plugin->priv = msd_keybindings_plugin_get_instance_private (plugin);
 
         g_debug ("MsdKeybindingsPlugin initializing");
 
@@ -99,11 +97,9 @@ msd_keybindings_plugin_class_init (MsdKeybindingsPluginClass *klass)
 
         plugin_class->activate = impl_activate;
         plugin_class->deactivate = impl_deactivate;
-
-        g_type_class_add_private (klass, sizeof (MsdKeybindingsPluginPrivate));
 }
 
 static void
 msd_keybindings_plugin_class_finalize (MsdKeybindingsPluginClass *klass)
 {
-}
\ No newline at end of file
+}
