@@ -31,14 +31,12 @@ struct MsdKeyboardPluginPrivate {
         MsdKeyboardManager *manager;
 };
 
-#define MSD_KEYBOARD_PLUGIN_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), MSD_TYPE_KEYBOARD_PLUGIN, MsdKeyboardPluginPrivate))
-
-MATE_SETTINGS_PLUGIN_REGISTER (MsdKeyboardPlugin, msd_keyboard_plugin)
+MATE_SETTINGS_PLUGIN_REGISTER_WITH_PRIVATE (MsdKeyboardPlugin, msd_keyboard_plugin)
 
 static void
 msd_keyboard_plugin_init (MsdKeyboardPlugin *plugin)
 {
-        plugin->priv = MSD_KEYBOARD_PLUGIN_GET_PRIVATE (plugin);
+        plugin->priv = msd_keyboard_plugin_get_instance_private (plugin);
 
         g_debug ("MsdKeyboardPlugin initializing");
 
@@ -99,8 +97,6 @@ msd_keyboard_plugin_class_init (MsdKeyboardPluginClass *klass)
 
         plugin_class->activate = impl_activate;
         plugin_class->deactivate = impl_deactivate;
-
-        g_type_class_add_private (klass, sizeof (MsdKeyboardPluginPrivate));
 }
 
 static void
