@@ -58,10 +58,6 @@
 #define TOUCHPAD_SCHEMA "org.mate.peripherals-touchpad"
 #define TOUCHPAD_ENABLED_KEY "touchpad-enabled"
 
-#define VOLUME_STEP 6
-
-#define MSD_MEDIA_KEYS_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MSD_TYPE_MEDIA_KEYS_MANAGER, MsdMediaKeysManagerPrivate))
-
 typedef struct {
         char   *application;
         guint32 time;
@@ -103,10 +99,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static void     msd_media_keys_manager_class_init  (MsdMediaKeysManagerClass *klass);
-static void     msd_media_keys_manager_init        (MsdMediaKeysManager      *media_keys_manager);
-
-G_DEFINE_TYPE (MsdMediaKeysManager, msd_media_keys_manager, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (MsdMediaKeysManager, msd_media_keys_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
 
@@ -542,6 +535,22 @@ do_calculator_action (MsdMediaKeysManager *manager)
         g_object_unref (settings);
 }
 
+static void
+do_messenger_action (MsdMediaKeysManager *manager)
+{
+        GSettings *settings;
+        char *messenger;
+
+        settings = g_settings_new ("org.mate.applications-messenger");
+        messenger = g_settings_get_string (settings, "exec");
+
+        if (messenger)
+                execute (manager, messenger, FALSE, FALSE);
+
+        g_free (messenger);
+        g_object_unref (settings);
+}
+
 static void
 do_shutdown_action (MsdMediaKeysManager *manager)
 {
@@ -716,9 +725,11 @@ do_sound_action (MsdMediaKeysManager *manager,
         volume_max = mate_mixer_stream_control_get_normal_volume (control);
 
         volume_step = g_settings_get_int (manager->priv->settings, "volume-step");
-        if (volume_step <= 0 ||
-            volume_step > 100)
-                volume_step = VOLUME_STEP;
+        if (volume_step <= 0 || volume_step > 100) {
+                GVariant *variant = g_settings_get_default_value (manager->priv->settings, "volume-step");
+                volume_step = g_variant_get_int32 (variant);
+                g_variant_unref (variant);
+        }
 
         /* Scale the volume step size accordingly to the range used by the control */
         volume_step = (volume_max - volume_min) * volume_step / 100;
@@ -1263,6 +1274,9 @@ do_action (MsdMediaKeysManager *manager,
         case CALCULATOR_KEY:
                 do_calculator_action (manager);
                 break;
+        case MESSENGER_KEY:
+                do_messenger_action (manager);
+                break;
         case PLAY_KEY:
                 return do_multimedia_player_action (manager, "Play");
         case PAUSE_KEY:
@@ -1601,14 +1615,12 @@ msd_media_keys_manager_class_init (MsdMediaKeysManagerClass *klass)
                               G_TYPE_STRING);
 
         dbus_g_object_type_install_info (MSD_TYPE_MEDIA_KEYS_MANAGER, &dbus_glib_msd_media_keys_manager_object_info);
-
-        g_type_class_add_private (klass, sizeof (MsdMediaKeysManagerPrivate));
 }
 
 static void
 msd_media_keys_manager_init (MsdMediaKeysManager *manager)
 {
-        manager->priv = MSD_MEDIA_KEYS_MANAGER_GET_PRIVATE (manager);
+        manager->priv = msd_media_keys_manager_get_instance_private (manager);
 }
 
 static gboolean
