@@ -53,8 +53,6 @@
 #include "mate-settings-profile.h"
 #include "msd-xrandr-manager.h"
 
-#define MSD_XRANDR_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MSD_TYPE_XRANDR_MANAGER, MsdXrandrManagerPrivate))
-
 #define CONF_SCHEMA                                    "org.mate.SettingsDaemon.plugins.xrandr"
 #define CONF_KEY_SHOW_NOTIFICATION_ICON                "show-notification-icon"
 #define CONF_KEY_USE_XORG_MONITOR_SETTINGS             "use-xorg-monitor-settings"
@@ -116,9 +114,7 @@ static const MateRRRotation possible_rotations[] = {
         /* We don't allow REFLECT_X or REFLECT_Y for now, as mate-display-properties doesn't allow them, either */
 };
 
-static void     msd_xrandr_manager_class_init  (MsdXrandrManagerClass *klass);
-static void     msd_xrandr_manager_init        (MsdXrandrManager      *xrandr_manager);
-static void     msd_xrandr_manager_finalize    (GObject             *object);
+static void msd_xrandr_manager_finalize (GObject *object);
 
 static void error_message (MsdXrandrManager *mgr, const char *primary_text, GError *error_to_display, const char *secondary_text);
 
@@ -130,7 +126,7 @@ static void get_allowed_rotations_for_output (MateRRConfig *config,
                                               int *out_num_rotations,
                                               MateRRRotation *out_rotations);
 
-G_DEFINE_TYPE (MsdXrandrManager, msd_xrandr_manager, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (MsdXrandrManager, msd_xrandr_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
 
@@ -2009,7 +2005,7 @@ monitor_activate_cb (GtkCheckMenuItem *item, gpointer data)
                 return;
         }
 
-        try_to_apply_intended_configuration (manager, NULL, gtk_get_current_event_time (), NULL); 
+        try_to_apply_intended_configuration (manager, NULL, gtk_get_current_event_time (), NULL);
 }
 
 static void
@@ -2060,7 +2056,7 @@ mirror_outputs_cb(GtkCheckMenuItem *item, gpointer data)
                 }
 
                 mate_rr_config_save (config, NULL);
-                try_to_apply_intended_configuration (manager, NULL, gtk_get_current_event_time (), NULL); 
+                try_to_apply_intended_configuration (manager, NULL, gtk_get_current_event_time (), NULL);
 
                 g_object_unref (config);
 
@@ -2073,7 +2069,7 @@ mirror_outputs_cb(GtkCheckMenuItem *item, gpointer data)
                 if (config == NULL)
                          run_display_capplet(GTK_WIDGET(item));
                 mate_rr_config_save (config, NULL);
-                try_to_apply_intended_configuration (manager, NULL, gtk_get_current_event_time (), NULL); 
+                try_to_apply_intended_configuration (manager, NULL, gtk_get_current_event_time (), NULL);
 
                 g_object_unref (config);
 
@@ -2172,19 +2168,19 @@ add_rotation_items_for_output (MsdXrandrManager *manager, MateRROutputInfo *outp
 static void
 add_enable_option_for_output (MsdXrandrManager *manager, MateRROutputInfo *output)
 {
-        struct MsdXrandrManagerPrivate *priv = manager->priv; 
+        struct MsdXrandrManagerPrivate *priv = manager->priv;
         GtkWidget *item;
         gulong activate_id;
 
         item = gtk_check_menu_item_new();
 
         if (mate_rr_output_info_is_active (output)){
-                gtk_menu_item_set_label (GTK_MENU_ITEM(item), "ON");
-                gtk_widget_set_tooltip_text(item, "Turn this monitor off");
+                gtk_menu_item_set_label (GTK_MENU_ITEM(item), _("ON"));
+                gtk_widget_set_tooltip_text(item, _("Turn this monitor off"));
         }
         else {
-                gtk_menu_item_set_label (GTK_MENU_ITEM(item), "OFF");
-                gtk_widget_set_tooltip_text(item ,"Turn this monitor on");
+                gtk_menu_item_set_label (GTK_MENU_ITEM(item), _("OFF"));
+                gtk_widget_set_tooltip_text(item, _("Turn this monitor on"));
         }
 
         gtk_widget_show_all (item);
@@ -2244,8 +2240,8 @@ add_menu_items_for_clone (MsdXrandrManager *manager)
         GtkWidget *item;
         gulong activate_id;
 
-        item = gtk_check_menu_item_new_with_label("Same output all monitors");
-        gtk_widget_set_tooltip_text(item, "Mirror same output to all monitors and turn them on");        
+        item = gtk_check_menu_item_new_with_label(_("Same output all monitors"));
+        gtk_widget_set_tooltip_text(item, _("Mirror same output to all monitors and turn them on"));
         gtk_widget_show_all (item);
         gtk_menu_shell_append (GTK_MENU_SHELL (priv->popup_menu), item);
         activate_id =  g_signal_connect (item, "activate",
@@ -2292,7 +2288,7 @@ status_icon_popup_menu (MsdXrandrManager *manager, guint button, guint32 timesta
         item = gtk_menu_item_new();
         box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
         image = gtk_image_new_from_icon_name ("preferences-system", GTK_ICON_SIZE_MENU);
-        label = gtk_label_new_with_mnemonic("_Configure Display Settings…");
+        label = gtk_label_new_with_mnemonic(_("_Configure Display Settings…"));
         /*Load the icon unless the user has icons in menus turned off*/
         icon_settings = g_settings_new ("org.mate.interface");
         if (g_settings_get_boolean (icon_settings, "menus-have-icons")){
@@ -2302,7 +2298,7 @@ status_icon_popup_menu (MsdXrandrManager *manager, guint button, guint32 timesta
             }
         gtk_container_add (GTK_CONTAINER (box), label);
         gtk_container_add (GTK_CONTAINER (item), box);
-        gtk_widget_set_tooltip_text(item, "Open the display configuration dialog (all settings)");
+        gtk_widget_set_tooltip_text(item, _("Open the display configuration dialog (all settings)"));
         g_signal_connect (item, "activate",
                           G_CALLBACK (popup_menu_configure_display_cb), manager);
         gtk_widget_show_all (item);
@@ -2310,7 +2306,7 @@ status_icon_popup_menu (MsdXrandrManager *manager, guint button, guint32 timesta
 
         g_signal_connect (priv->popup_menu, "selection-done",
                           G_CALLBACK (status_icon_popup_menu_selection_done_cb), manager);
-                          
+
         /*Set up custom theming and forced transparency support*/
         GtkWidget *toplevel = gtk_widget_get_toplevel (priv->popup_menu);
         /*Fix any failures of compiz/other wm's to communicate with gtk for transparency */
@@ -2673,8 +2669,6 @@ msd_xrandr_manager_class_init (MsdXrandrManagerClass *klass)
         object_class->finalize = msd_xrandr_manager_finalize;
 
         dbus_g_object_type_install_info (MSD_TYPE_XRANDR_MANAGER, &dbus_glib_msd_xrandr_manager_object_info);
-
-        g_type_class_add_private (klass, sizeof (MsdXrandrManagerPrivate));
 }
 
 static guint
@@ -2692,7 +2686,7 @@ get_keycode_for_keysym_name (const char *name)
 static void
 msd_xrandr_manager_init (MsdXrandrManager *manager)
 {
-        manager->priv = MSD_XRANDR_MANAGER_GET_PRIVATE (manager);
+        manager->priv = msd_xrandr_manager_get_instance_private (manager);
 
         manager->priv->switch_video_mode_keycode = get_keycode_for_keysym_name (VIDEO_KEYSYM);
         manager->priv->rotate_windows_keycode = get_keycode_for_keysym_name (ROTATE_KEYSYM);
